;; think/theme.jl

;; Trying to create something new
;; Made by Rafael Garca Gallego
;; <rgarcia@eurielec.etsit.upm.es>

(let* (

(title-width
  (lambda (w)
  (let
      ((w-width (car (window-dimensions w))))
    (max 0 (min (- w-width 15) (+ 45 (text-width (window-name w))))))))

  (update-text-width
     (lambda (w)
      (if (eq (window-get w 'current-frame-style) 'think)
          (rebuild-frame w))))

;;  (font (get-font "-b&h-lucida-bold-r-normal-*-*-100-*-*-p-*-iso8859-1"))

  (font-colors (list (get-color "#6e6e6e") (get-color "yellow")))

  (colors (list (get-color "#021975") (get-color "#3546b2")))

  (separator-colors (list (get-color "yellow") (get-color "#f7f431")))

  (standart-corner (make-image "corner.png"))

  (iconify-images (list standart-corner (make-image "iconify-corner.png") (make-image "iconify-corner-hl.png") (make-image "iconify-corner-pressed.png")))

  (menu-images (list (flip-image-horizontally (copy-image standart-corner)) (make-image "menu-corner.png") (make-image "menu-corner-hl.png")(make-image "menu-corner-pressed.png")))

  (maximize-images-normal (list (flip-image-diagonally (copy-image standart-corner)) (make-image "maximize-corner-normal.png") (make-image "maximize-corner-normal-hl.png") (make-image "maximize-corner-normal-pressed.png")))

  (maximize-images-shaped (list (flip-image-vertically (copy-image standart-corner)) (make-image "maximize-corner-shaped.png") (make-image "maximize-corner-shaped-hl.png") (make-image "maximize-corner-shaped-pressed.png")))

  (close-images-normal (list (make-image "square.png") (make-image "close-square.png") (make-image "close-square-hl.png") (make-image "close-square-pressed.png")))

  (close-images-shaped (list (flip-image-diagonally (copy-image standart-corner)) (make-image "close-corner.png") (make-image "close-corner-hl.png") (make-image "close-corner-pressed.png")))

  (standart-resizer-inactive (make-image "resizer-inactive.png"))

  (standart-resizer-active (make-image "resizer-active.png"))

  (standart-resizer-hl (make-image "resizer-hl.png"))

  (standart-resizer-pressed (make-image "resizer-pressed.png"))

  (resizer-images-bottom-right (list standart-resizer-inactive standart-resizer-active standart-resizer-hl standart-resizer-pressed))

  (resizer-images-bottom-left (list (flip-image-horizontally (copy-image standart-resizer-inactive)) (flip-image-horizontally (copy-image standart-resizer-active)) (flip-image-horizontally (copy-image standart-resizer-hl)) (flip-image-horizontally (copy-image standart-resizer-pressed))))

  (resizer-images-top-right (list (flip-image-vertically (copy-image standart-resizer-inactive)) (flip-image-vertically (copy-image standart-resizer-active)) (flip-image-vertically (copy-image standart-resizer-hl)) (flip-image-vertically (copy-image standart-resizer-pressed))))

(frame
 `(
   ;; Bar
   ((background . ,colors)
    (foreground . ,font-colors)
;;    (font . ,font)
    (text . ,window-name)
    (top-edge . -13)
    (height . 11)
    (left-edge . 0)
    (width . ,(lambda (w) (title-width w)))
    (x-justify . center)
    (y-justify . center)
    (class . title))

   ;; Other frame borders...
   ((background . ,separator-colors)
    (top-edge . -15)
    (left-edge . 0)
    (height . 2)
    (width . ,(lambda (w) (title-width w))))

   ((background . ,separator-colors)
    (top-edge . -2)
    (left-edge . 0)
    ;; If we want no upper bar
    ;; (width . ,(lambda (w) (title-width w)))
    ;; we have to suppress right-edge too...
    (right-edge . 0)
    (height . 2)
    (class . title))

   ;; You may want to suppress this one too

   ((background . ,separator-colors)
    (top-edge . 0)
    (left-edge . -2)
    (width . 2)
    (bottom-edge . 0)
    (class . title))

   ;; And of course this tow ones...

   ((background . ,separator-colors)
    (bottom-edge . -2)
    (left-edge . 0)
    (right-edge . 0)
    (height . 2)
    (class . bottom-border))

   ((background . ,separator-colors)
    (right-edge . -2)
    (top-edge . 0)
    (bottom-edge . 0)
    (width . 2)
    (class . right-border))

   ;; Iconify Button
   ((background . ,iconify-images)
    (top-edge . -15)
    (left-edge . ,(lambda (w) (title-width w)))
    (height . 15)
    (width . 15)
    (class . iconify-button))

    ;; Menu Button
    ((background . ,menu-images)
     (top-edge . -15)
     (left-edge . -15)
     (height . 15)
     (width . 15)
     (class . menu-button))

    ;; Close button

    ((background . ,close-images-normal)
     (top-edge . 0)
     (left-edge . -15)
     (height . 15)
     (width . 15)
     (class . close-button))

    ;; Maximize Button
    ((background . ,maximize-images-normal)
     (top-edge . 15)
     (left-edge . -15)
     (height . 15)
     (width . 15)
     (class . maximize-button))

    ;; Making it resizeable...
    ((background . ,resizer-images-bottom-right)
     (bottom-edge . -6)
     (right-edge . -6)
     (height . 15)
     (width . 15)
     (class . bottom-right-corner))

   ((background . ,resizer-images-bottom-left)
    (bottom-edge . -6)
    (left-edge . -6)
    (height . 15)
    (width . 15)
    (class . bottom-left-corner))

   ((background . ,resizer-images-top-right)
    (top-edge . -6)
    (right-edge . -6)
    (height . 15)
    (width . 15)
    (class . top-right-corner))

))

(shaped-frame
 `(

  ;; mmm that may be different

   ;; Bar
   ((background . ,colors)
    (foreground . ,font-colors)
;;    (font . ,font)
    (text . ,window-name)
    (top-edge . -13)
    (height . 11)
    (left-edge . 0)
    (width . ,(lambda (w) (title-width w)))
    (x-justify . center)
    (y-justify . center)
    (class . title))

   ;; Other frame borders...
   ((background . ,separator-colors)
    (top-edge . -15)
    (left-edge . 0)
    (height . 2)
    (width . ,(lambda (w) (title-width w))))

   ((background . ,separator-colors)
    (top-edge . -2)
    (left-edge . 0)
    (height . 2)
    (width . ,(lambda (w) (title-width w))))

   ;; Iconify Button
   ((background . ,iconify-images)
    (top-edge . -15)
    (left-edge . ,(lambda (w) (title-width w)))
    (height . 15)
    (width . 15)
    (class . iconify-button))

    ;; Menu Button
    ((background . ,menu-images)
     (top-edge . -15)
     (left-edge . -15)
     (height . 15)
     (width . 15)
     (class . menu-button))

    ;; Close Button
    ((background . ,close-images-shaped)
     (top-edge . 0)
     (left-edge . -15)
     (height . 15)
     (width . 15)
     (class . close-button))

    ;; Maximize Button
    ((background . ,maximize-images-shaped)
     (top-edge . 0)
     (left-edge . 0)
     (height . 15)
     (width . 15)
     (class . maximize-button))

))
 
(transient-frame
 `(
   ;; Bar
   ((background . ,colors)
    (foreground . ,font-colors)
;;    (font . ,font)
    (text . ,window-name)
    (top-edge . -13)
    (height . 11)
    (left-edge . 0)
    (width . ,(lambda (w) (title-width w)))
    (x-justify . center)
    (y-justify . center)
    (class . title))

    ;; Other frame borders...
   ((background . ,separator-colors)
    (top-edge . -15)
    (left-edge . 0)
    (height . 2)
    (width . ,(lambda (w) (title-width w)))
    (class . title))

   ((background . ,separator-colors)
    (top-edge . -2)
    (left-edge . 0)
    (height . 2)
    ;; Again u-comment it and so
    ;;(width . ,(lambda (w) (title-width w))
    (right-edge . 0)
    (class . title))

   ((background . ,separator-colors)
    (left-edge . -2)
    (top-edge . -15)
    (width . 2)
    ;; And soooooo
    ;;(height . 15)
    (bottom-edge . 0)
    (class . title))

   ((background . ,separator-colors)
    (top-edge . -15)
    (left-edge . ,(lambda (w) (title-width w)))
    (width . 2)
    (height . 15)
    (class . title))

   ((background . ,separator-colors)
    (right-edge . -2)
    (top-edge . 0)
    (bottom-edge . 0)
    (width . 2)
    (class . title))

  ((background . ,separator-colors)
   (bottom-edge . -2)
   (left-edge . 0)
   (right-edge . 0)
   (height . 2)
   (class . title))

))

(shaped-transient-frame
`(

   ;; Bar
   ((background . ,colors)
    (foreground . ,font-colors)
;;    (font . ,font)
    (text . ,window-name)
    (top-edge . -13)
    (height . 11)
    (left-edge . 0)
    (width . ,(lambda (w) (title-width w)))
    (x-justify . center)
    (y-justify . center)
    (class . title))

    ;; Other frame borders...
   ((background . ,separator-colors)
    (top-edge . -15)
    (left-edge . 0)
    (height . 2)
    (width . ,(lambda (w) (title-width w)))
    (class . title))

   ((background . ,separator-colors)
    (top-edge . -2)
    (left-edge . 0)
    (height . 2)
    (width . ,(lambda (w) (title-width w)))
    (class . title))

   ((background . ,separator-colors)
    (left-edge . -2)
    (top-edge . -15)
    (width . 2)
    (height . 15)
    (class . title))

   ((background . ,separator-colors)
    (top-edge . -15)
    (left-edge . ,(lambda (w) (title-width w)))
    (width . 2)
    (height . 15)
    (class . title))

))

)

  (add-frame-style 'think
                   (lambda (w type)
                     (cond ((eq type 'shaped)
                            shaped-frame)
                           ((eq type 'transient)
                            transient-frame)
                           ((eq type 'shaped-transient)
                            shaped-transient-frame)
                           ((eq type 'unframed)
                            nil-frame)
                           (t
                            frame))))

 (call-after-property-changed 'WM_NAME update-text-width))
